#!/bin/bash

#SBATCH --job-name=DeviceQuery
#SBATCH --output=output.txt
#SBATCH --error=output.txt

#SBATCH --partition=gpu
#SBATCH --gres=gpu:1
#SBATCH --account=ams301

#SBATCH --ntasks=1
#SBATCH --cpus-per-task=8
#SBATCH --time=00:01:00

## load modules

host=`hostname`
if [[ "x$host" == xnode* || "x$host" == xcholesky* ]]
then
  module purge
  module load gcc/13.2.0
  module load cuda/12.4
fi

## compilation

mkdir -p install/cuda install/opencl

d=`which nvcc`
if [[ "x$d" == "x" ]]
then
  echo "cannot find nvcc (cuda compiler)"
  exit -1
fi

d=`dirname $d`
CUDA_ROOT=`dirname $d`

## execution

nvcc src/cuda/deviceQuery.cpp -I src/cuda -o install/cuda/deviceQuery

echo 
echo '________________'
echo 'Cuda deviceQuery'
echo

 install/cuda/deviceQuery


if [ -e $CUDA_ROOT/lib/libOpenCL.so ]
then
  OPENCL_LIBDIR=$CUDA_ROOT/lib
  export LD_LIBRARY_PATH=$OPENCL_LIBDIR:$LD_LIBRARY_PATH
elif [ -e $CUDA_ROOT/lib64/libOpenCL.so ]
then
  OPENCL_LIBDIR=$CUDA_ROOT/lib64
  export LD_LIBRARY_PATH=$OPENCL_LIBDIR:$LD_LIBRARY_PATH
fi

if [ ! "x$OPENCL_LIBDIR" == "x" ]
then
 nvcc src/opencl/deviceQuery.cpp -o install/opencl/deviceQuery_nvcc -L $OPENCL_LIBDIR -lOpenCL

 echo 
 echo '__________________'
 echo 'OpenCL deviceQuery (nvcc)'
 echo

 install/opencl/deviceQuery_nvcc
fi
echo
