#!/bin/bash

#SBATCH --job-name=DeviceQuery
#SBATCH --output=output.txt
#SBATCH --error=output.txt

#SBATCH --partition=gpu
#SBATCH --gres=gpu:1
#SBATCH --account=ams301

#SBATCH --ntasks=1
#SBATCH --time=00:01:00

## load modules

echo
host=`hostname`
echo $host
if [[ "x$host" == xcholesky* ]]
then
  module purge
  module load gcc/13.2.0
  module load cuda/12.4
fi

d=`which nvcc`
if [[ "x$d" == "x" ]]
then
  echo "cannot find nvcc (cuda compiler)"
  exit -1
fi

d=`dirname $d`
CUDA_ROOT=`dirname $d`

if [ -e $CUDA_ROOT/lib/libOpenCL.so ]
then
  OPENCL_LIBDIR=$CUDA_ROOT/lib
  export LD_LIBRARY_PATH=$OPENCL_LIBDIR:$LD_LIBRARY_PATH
elif [ -e $CUDA_ROOT/lib64/libOpenCL.so ]
then
  OPENCL_LIBDIR=$CUDA_ROOT/lib64
  export LD_LIBRARY_PATH=$OPENCL_LIBDIR:$LD_LIBRARY_PATH
fi
echo

## compilation

echo nvcc -DCL_TARGET_OPENCL_VERSION=300 add_vectors.c -L${CUDA_ROOT}/lib64 -lOpenCL -o add_nvcc_opencl
nvcc -g -DCL_TARGET_OPENCL_VERSION=300 add_vectors.c -L${CUDA_ROOT}/lib64 -lOpenCL -o add_nvcc_opencl

echo ./add_nvcc_opencl 
./add_nvcc_opencl 

if [[ "x$host" == xcholesky* ]]
then
  module purge
  module load intel_compiler/oneapi_2023.2.0
fi

d=`which icx`
d=`dirname $d`
ONEAPI_ROOT=`dirname $d`

if [ -e $ONEAPI_ROOT/lib/libOpenCL.so ]
then
  OPENCL_LIBDIR=$ONEAPI_ROOT/lib
  export LD_LIBRARY_PATH=$OPENCL_LIBDIR:$LD_LIBRARY_PATH
elif [ -e $ONEAPI_ROOT/lib/sycl/libOpenCL.so ]
then
  OPENCL_LIBDIR=$ONEAPI_ROOT/lib/sycl
  export LD_LIBRARY_PATH=$OPENCL_LIBDIR:$LD_LIBRARY_PATH
fi

if [ -e $ONEAPI_ROOT/include/CL/cl.h ]
then
  OPENCL_INCDIR=$ONEAPI_ROOT/include
elif [ -e $ONEAPI_ROOT/include/sycl/CL/cl.h ]
then
  OPENCL_INCDIR=$ONEAPI_ROOT/include/sycl
fi

echo icx add_vectors.c -DCL_TARGET_OPENCL_VERSION=300 -I $OPENCL_INCDIR -L $OPENCL_LIBDIR -lOpenCL -o add_intel_opencl
icx add_vectors.c -DCL_TARGET_OPENCL_VERSION=300 -I $OPENCL_INCDIR -L $OPENCL_LIBDIR -lOpenCL -o add_intel_opencl

echo ./add_intel_opencl
./add_intel_opencl 
