#!/bin/bash

#SBATCH --job-name=DeviceQuery
#SBATCH --output=output.txt
#SBATCH --error=output.txt

#SBATCH --partition=gpu
#SBATCH --gres=gpu:1
#SBATCH --account=ams301

#SBATCH --ntasks=1
#SBATCH --cpus-per-task=8
#SBATCH --time=00:03:00

## load modules

host=`hostname`
if [[ "x$host" == xnode* || "x$host" == xcholesky* ]]
then
  module purge
  module load cmake/3.29.3
  module load gcc/13.2.0
  module load cuda/12.4
fi
c=`which nvcc`
c=`dirname $c`
export CUDA_HOME=`dirname $c`

## compilation

export OCL_ROOT=${CUDA_HOME}

cmake -DOpenCL_LIBRARY=${OCL_ROOT}/lib64/libOpenCL.so \
      -DOpenCL_INCLUDE_DIR=${OCL_ROOT}/include \
      -B build -S src -DCMAKE_INSTALL_PREFIX=install

make -j 8 VERBOSE=1 -C build --no-print-directory install

install/image_CPU
OMP_NUM_THREADS=8 install/image_CPU_OpenMP
install/image_GPU_Cuda
install/image_GPU_OpenCL

echo
